from os import mkdir, rmdir, remove
from os.path import isdir, isfile, join
from shutil import copy
from random import randrange

from django.conf import settings
from django.test import TestCase

from django_broom import utils
from django_broom.tests.helpers import random_string


class GetFilesTest(TestCase):

    def setUp(self):

        directory_name = 'test-%s' % random_string()
        self.directory = join(settings.MEDIA_ROOT, directory_name)
        self.files = []

    def tearDown(self):

        if len(self.files) > 0:
            for file_name in self.files:
                path_to_file = join(self.directory, file_name)

                if isfile(path_to_file):
                    remove(path_to_file)

        if isdir(self.directory):
            rmdir(self.directory)

    def test_method_when_no_directory(self):
        """ Returns empty list when directory is not found """

        files = utils.get_files(self.directory)

        assert len(files) == 0

    def test_method_when_empty_directory(self):
        """ Returns empty list when directory is empty """

        mkdir(self.directory)
        files = utils.get_files(self.directory)

        assert len(files) == 0

    def test_method(self):
        """ Returns list of all files """

        mkdir(self.directory)

        for file_number in range(0, randrange(1, 10, 1)):
            file_name = 'image-%s.png' % file_number
            self.files.append(file_name)

            path_to_file = join(self.directory, file_name)
            copy(join(settings.MEDIA_ROOT, 'image.png'), path_to_file)

        files = utils.get_files(self.directory)

        assert len(files) == len(self.files)

        for file_name in self.files:
            assert file_name in files


class RemoveFileTest(TestCase):

    def setUp(self):

        directory_name = 'test-%s' % random_string()
        self.directory = join(settings.MEDIA_ROOT, directory_name)

        file_name = 'image-%s.png' % random_string()
        self.file = join(self.directory, file_name)

        mkdir(self.directory)

    def tearDown(self):

        if isfile(self.file):
            remove(self.file)

        if isdir(self.directory):
            rmdir(self.directory)

    def test_method_when_no_file(self):
        """ Returns `False` when file is not found """

        assert utils.remove_file(self.file) is False

    def test_method_file(self):
        """ Returns `True` when file is removed """

        copy(join(settings.MEDIA_ROOT, 'image.png'), self.file)

        assert utils.remove_file(self.file) is True
