from os import listdir, remove
from os.path import isdir, isfile, join

from django.conf import settings


def get_files(directory):
    """
    Finds and retrieves all files within the specified directory.

    Parameters
    ----------
    directory : str
        Directory where files should be retrieved from.

    Returns
    -------
    list
        List of all files found.
    """

    path_to_directory = join(settings.MEDIA_ROOT, directory)
    files = []

    if isdir(path_to_directory):
        for file_name in listdir(path_to_directory):
            if isfile(join(path_to_directory, file_name)):
                files.append(file_name)

    return files


def remove_file(path_to_file):
    """
    Removes the specified file.

    Parameters
    ----------
    path_to_file : str
        Path to file for removal.

    Returns
    -------
    bool
        Whether file was removed.
    """

    if isfile(path_to_file):
        remove(path_to_file)
        return True
    else:
        return False
